@@ -20,12 +20,18 @@ import relex.ParsedSentence;
 import relex.concurrent.RelexContext;
 
 /**
- * SentenceAlgorithmApplier is responsible for loading SentenceAlgorithms from a
- * file, and applying them to a ParsedSentence.
+ * SentenceAlgorithmApplier is responsible for loading SentenceAlgorithms
+ * from a file, and applying them to a ParsedSentence.
+ *
+ * Several different sets of algorithms may be applied. The core set 
+ * include basic feature tagging and semantic extraction. Optional sets
+ * include a Stanford-parser comptibility mode, and a Penn Treebank POS
+ * tagging compatibility mode.
  */
 public class SentenceAlgorithmApplier
 {
 	private AlgorithmApplier tagger;
+	private AlgorithmApplier penn;
 	private AlgorithmApplier semant;
 	private AlgorithmApplier stanford;
 
@@ -35,6 +41,8 @@ public class SentenceAlgorithmApplier
 			"relex.tagalgpath", "relex-tagging-algs.txt");
 		semant = new AlgorithmApplier(
 			"relex.semalgpath", "relex-semantic-algs.txt");
+		penn = new AlgorithmApplier(
+			"relex.pennalgpath", "relex-penn-tagging-algs.txt");
 		stanford = new AlgorithmApplier(
 			"relex.sfalgpath", "relex-stanford-algs.txt");
 	}
@@ -54,7 +62,12 @@ public class SentenceAlgorithmApplier
 		stanford.applyAlgs(sentence, context);
 	}
 
-	// The apply method!
+	public void pennTag(ParsedSentence sentence, RelexContext context)
+	{
+		penn.applyAlgs(sentence, context);
+	}
+
+	// The apply method, for the core relations only.
 	public void applyAlgs(ParsedSentence sentence, RelexContext context)
 	{
 		tagger.applyAlgs(sentence, context);
