@@ -290,13 +290,15 @@ public class LinkableView extends View // implements TreeNode , LinkNode
 		    wordString.endsWith("[~]"))
 		{
 			len = wordString.length(); // recompute length, due to above dots.
-			wordString = wordString.substring(0,len-3);
+			wordString = wordString.substring(0, len-3);
 		}
 
 		FeatureNode f = new FeatureNode(wordString);
 		ths.set(WORD_STRING_FEATURE_NAME, f);
 
 		// The MorphyAlg will modify the above, so make a copy of the original.
+		// (Literally a copy -- this has to be a distinct feature node.)
+		f = new FeatureNode(wordString);
 		ths.set(ORIG_WORD_STRING_FEATURE_NAME, f);
 	}
 
@@ -325,7 +327,11 @@ public class LinkableView extends View // implements TreeNode , LinkNode
 	}
 
 	public void setEntityFlag() {
-		fn().set("ENTITY-FLAG", new FeatureNode("T"));
+		setEntityFlag(fn());
+	}
+	
+	public static void setEntityFlag(FeatureNode ths) {
+		ths.set("ENTITY-FLAG", new FeatureNode("T"));
 	}
 	
 	public boolean hasEntityFlag()	{
@@ -496,8 +502,9 @@ public class LinkableView extends View // implements TreeNode , LinkNode
 		setCharIndices(fn(), start, end, indexInSentence);
 	}
 
-	public void setCharIndices(FeatureNode ths, int start, int end,
-			int indexInSentence) {
+	public static void setCharIndices(FeatureNode ths,
+	                           int start, int end, int indexInSentence)
+	{
 		throwIfNoFN(ths);
 		FeatureNode f = ths.get(START_NAME);
 		if (f == null) {
