@@ -146,7 +146,8 @@ public class LocalLGParser extends LGParser
 						LinkableView.setPrev(fn, lastFN);
 					}
 
-					if (LinkGrammar.isEntity(wordString) || Character.isUpperCase(wordString.charAt(0)))
+					// XXX This should be removed, it really doesn't belong here.
+					if (Character.isUpperCase(wordString.charAt(0)))
 						LinkableView.setEntityFlag(fn);
 
 					s.addWord(fn);
@@ -154,7 +155,7 @@ public class LocalLGParser extends LGParser
 					// Add char-index information to the feature node
 					// FYI, the JNI call (*env)->NewStringUTF(env, str);
 					// will return NULL if str is utf8-encoded Japanese or Chinese. Go figure.
-					String tokenString = LinkGrammar.getWord(w);
+					String tokenString = wordString;
 					if (null != tokenString) tokenString = tokenString.toLowerCase(); // normalize cases
 					else tokenString = "";
 
@@ -188,8 +189,6 @@ public class LocalLGParser extends LGParser
 			FeatureNode meta = new FeatureNode();
 			meta.set("num_skipped_words", new FeatureNode(Integer.toString(
 					LinkGrammar.getNumSkippedWords())));
-			meta.set("and_cost", new FeatureNode(Integer.toString(
-					LinkGrammar.getLinkageAndCost())));
 			meta.set("disjunct_cost", new FeatureNode(Integer.toString(
 					LinkGrammar.getLinkageDisjunctCost())));
 			meta.set("link_cost", new FeatureNode(Integer.toString(
@@ -200,7 +199,7 @@ public class LocalLGParser extends LGParser
 
 			// add linkage and tree structure
 			if (verbosity >= 5) System.err.println("Adding Linkage Structure");
-			addLinkageStructure(s, ignoreFirst, ignoreLast, config.isLoadSense());
+			addLinkageStructure(s, ignoreFirst, ignoreLast, config.isStoreSense());
 			if (config.isStoreConstituentString())
 			{
 				if (verbosity >= 5) System.err.println("Adding Tree Structure");
